# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You
# may not use this file except in compliance with the License. A copy of
# the License is located at
#
#     http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is
# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific
# language governing permissions and limitations under the License.
import os

HISTORY_FILENAME_ENV_VAR = 'AWS_CLI_HISTORY_FILE'
DEFAULT_HISTORY_FILENAME = os.path.expanduser(
    os.path.join('~', '.aws', 'cli', 'history', 'history.db')
)
